package net.minecraft.src.forestry.api;

import net.minecraft.src.ItemStack;

/**
 * Provides an interface to the recipe manager of the centrifuge. 
 *
 * The manager is initialized at the beginning of Forestry's BaseMod.load() cycle.
 * Begin adding recipes in BaseMod.ModsLoaded() and this shouldn't be null even if
 * your mod loads before Forestry.
 *
 * Accessible via {@link ForestryAPI.centrifugeManager}
 *
 * @author SirSengir
 */
public interface ICentrifugeManager {
	/**
	 * Add a recipe to the centrifuge
	 * @param timePerItem Time to centrifugate one item of the given type
	 * @param resource ItemStack containing information on item id and damage. Stack size will be ignored.
	 * @param primary Primary product produced by centrifugating one item. Yield 100 %.
	 * @param secondary Secondary product that may be produced when centrifugating the given item. May be null.
	 * @param chance Chance (1 - 100) for centrifugation to yield the secondary product.
	 */
	public void addRecipe(int timePerItem, ItemStack resource, ItemStack primary, ItemStack secondary, int chance);
	/**
	 * Add a recipe to the centrifuge
	 * @param timePerItem Time to centrifugate one item of the given type
	 * @param resource ItemStack containing information on item id and damage. Stack size will be ignored.
	 * @param primary Primary product produced by centrifugating one item. Yield 100 %.
	 */
	public void addRecipe(int timePerItem, ItemStack resource, ItemStack primary);
}
